EnhancedCompositedTransformAligned class

Implemented types
Implementers
Annotations

Constructors

EnhancedCompositedTransformAligned({required Alignment follower, required Alignment target, Alignment portal = Alignment.center, AxisFlag alignToPortal = const AxisFlag(), AxisFlag shiftToWithinBound = const AxisFlag(), Offset offset = Offset.zero, EnhancedCompositedTransformAnchor? backup, String? debugName})
const

Properties

alignToPortal → AxisFlag
Whether to use portal instead of target for X and/or Y axis
final
backup → EnhancedCompositedTransformAnchor?
If the calculated position would render the follower element out of bounds (for example, a tooltip would go off screen), a backup can be used. The offset calculations will fall back to the backup.
final
debugName → String?
final
follower → Alignment
The reference point on the follower element.
final
hashCode → int
The hash code for this object.
no setteroverride
offset → Offset
Offset to shift the follower element by after all calculations are made.
final
portal → Alignment
The reference point on the Portal, if enabled
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shiftToWithinBound → AxisFlag
for X and/or Y axis
final
target → Alignment
The reference point on the target element, if enabled
final

Methods

getFollowerOffset({required Size followerSize, required Size targetSize, required Rect theaterRect}) → Offset
Returns the offset at which to position the follower element in relation to the top left of the targetSize.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override